@@ -125,31 +125,35 @@ class DicomModalities:
         """
         self._move(
             level="Study",
-            dicom_tag_identifier="StudyInstanceUID",
-            dicom_id=dicom_id,
+            resource={
+                "StudyInstanceUID": dicom_id
+            },
             from_modality=from_modality,
             to_modality_aet=to_modality_aet
         )
 
-    def move_series(self, from_modality: str, dicom_id: str, to_modality_aet: str = None):
+    def move_series(self, from_modality: str, dicom_id: str, study_dicom_id: str, to_modality_aet: str = None):
         """
         moves a series from a remote modality (C-Move) to a target modality (AET)
 
         this call is synchronous.  It completes once the C-Move is complete.
 
         :param from_modality: the modality alias configured in orthanc
-        :param dicom_id: the SeriesInstanceUid of the series to move
+        :param dicom_id: the SeriesInstanceUID of the series to move
+        :param study_dicom_id: the StudyInstanceUID of the parent study
         :param to_modality_aet: the AET of the target modality
         """
         self._move(
             level="Series",
-            dicom_tag_identifier="SeriesInstanceUID",
-            dicom_id=dicom_id,
+            resource={
+                "SeriesInstanceUID": dicom_id,
+                "StudyInstanceUID": study_dicom_id
+            },
             from_modality=from_modality,
             to_modality_aet=to_modality_aet
         )
 
-    def move_instance(self, from_modality: str, dicom_id: str, to_modality_aet: str = None):
+    def move_instance(self, from_modality: str, dicom_id: str, series_dicom_id: str, study_dicom_id: str, to_modality_aet: str = None):
         """
         moves an instance from a remote modality (C-Move) to a target modality (AET)
 
@@ -157,30 +161,34 @@ class DicomModalities:
 
         :param from_modality: the modality alias configured in orthanc
         :param dicom_id: the SOPInstanceUid of the instance to move
+        :param series_dicom_id: the SeriesInstanceUID of the parent series
+        :param study_dicom_id: the StudyInstanceUID of the parent study
         :param to_modality_aet: the AET of the target modality
         """
         self._move(
             level="Instance",
-            dicom_tag_identifier="SOPInstanceUid",
-            dicom_id=dicom_id,
+            resource={
+                "SOPInstanceUID": dicom_id,
+                "SeriesInstanceUID": series_dicom_id,
+                "StudyInstanceUID": study_dicom_id
+            },
             from_modality=from_modality,
             to_modality_aet=to_modality_aet
         )
 
-    def _move(self, level: str, dicom_tag_identifier: str, from_modality: str, dicom_id: str, to_modality_aet: str = None):
+    def _move(self, level: str, resource: object, from_modality: str, to_modality_aet: str = None):
         """
         moves a study from a remote modality (C-Move) to a target modality (AET)
 
         this call is synchronous.  It completes once the C-Move is complete.
 
         :param from_modality: the modality alias configured in orthanc
-        :param dicom_id: the StudyInstanceUid of the study to retrieve
         :param to_modality_aet: the AET of the target modality
         """
 
         payload = {
             'Level': level,
-            'Resources': [{dicom_tag_identifier: dicom_id}]
+            'Resources': [resource]
         }
 
         if to_modality_aet:
